==> eskuel_1.0.5.orig.tar.gz: eskuel-1.0.5/lang/english.inc.php <==
<?php
$txt['config_name'] = 'english';
$txt['charset'] = 'ISO-8859-1';

$txt['Yes'] = 'Yes';
$txt['No'] = 'No';
$txt['language'] = 'Language';
$txt['close'] = 'Close';
$txt['create_tbl'] = 'Create a new table';
$txt['add_field'] = 'Add a field';
$txt['change_type'] = 'Change type';
$txt['select'] = 'Select';
$txt['options'] = 'Options';
$txt['setup'] = 'Setup';
$txt['install'] = 'Installation';
$txt['create_db'] = 'Create a database';
$txt['manual_request'] = 'Manual query';
$txt['delete_db'] = 'Delete this database';
$txt['display_content'] = 'Show the content';
$txt['add_record'] = 'Add a record';
$txt['add_comment'] = 'Modify comment';
$txt['dump_tbl'] = 'Dump the table';
$txt['rename_tbl'] = 'Rename the table';
$txt['copy_tbl'] = 'Copy the table';
$txt['move_tbl'] = 'Move the table';
$txt['order_tbl'] = 'Order table';
$txt['order_tbl_by'] = 'Order table by';
$txt['delete_tbl'] = 'Drop the table';
$txt['delete_tbls'] = 'Drop the tables';
$txt['check_tbl'] = 'Check the table';
$txt['analyse_tbl'] = 'Analyze the table';
$txt['repare_tbl'] = 'Repair the table';
$txt['optimize_tbl'] = 'Optimize the table';
$txt['optimize_tbls'] = 'Optimize the tables';
$txt['back_2_tbl'] = 'Back to table';
$txt['back_2_db'] = 'Back to database';
$txt['execute'] = 'Execute';
$txt['no_tbl'] = 'No table in this database.';
$txt['tbl'] = 'Table';
$txt['db'] = 'Database';
$txt['records'] = 'Records';
$txt['size'] = 'Size';
$txt['records2'] = 'record(s)';
$txt['tbl_name'] = 'Table\'s name';
$txt['nb_fields'] = 'Number of fields';
$txt['create_the_tbl'] = 'Create the table';
$txt['tbl_creation'] = 'Creating table';
$txt['key'] = 'Key';
$txt['field_name'] = 'Field\'s name';
$txt['type'] = 'Type';
$txt['can_be_null'] = 'Can be null';
$txt['length'] = 'Length';
$txt['primary'] = 'Primary';
$txt['index'] = 'Index';
$txt['unique'] = 'Unique';
$txt['fulltext'] = 'Full text';
$txt['attribs'] = 'Attributes';
$txt['default_value'] = 'Default value';
$txt['auto_incr'] = 'Auto increment';
$txt['comments'] = 'Comments';
$txt['sql_query'] = 'SQL Query';
$txt['tbl_created'] = 'Table has been successfully created';
$txt['no_records'] = 'No records';
$txt['from'] = 'From';
$txt['to'] = 'to';
$txt['modify'] = 'Modify';
$txt['delete'] = 'Delete';
$txt['cancel'] = 'Cancel';
$txt['query_done'] = 'Query done';
$txt['confirm_query'] = 'Are you sure you want to do';
$txt['query_is_about'] = 'The query concern';
$txt['tbl2'] = 'table(s)';
$txt['and'] = 'and';
$txt['the_db'] = 'The database';
$txt['has_been_created'] = 'has been created';
$txt['db_name'] = 'Database\'s name';
$txt['create_the_db'] = 'Create the database';
$txt['name'] = 'Name';
$txt['xtra'] = 'Extra';
$txt['choice'] = 'Selection';
$txt['delete_choice'] = 'Delete selection';
$txt['modif_choice'] = 'Modify selection';
$txt['field'] = 'Field';
$txt['fields'] = 'Fields';
$txt['never_done'] = 'Never done';
$txt['next_auto'] = 'Next "auto_increment"';
$txt['tbl_comment'] = 'Table comment';
$txt['type_records'] = 'Records type';
$txt['record_size'] = 'Average record size';
$txt['data_size'] = 'Data size';
$txt['index_size'] = 'Index size';
$txt['creation_date'] = 'Creation date';
$txt['last_update_date'] = 'Last update';
$txt['last_check_date'] = 'Last check';
$txt['lost_space'] = 'Warning lost space';
$txt['unit'] = 'octets';
$txt['comment_recorded'] = 'Comment saved';
$txt['a_comment'] = 'Comment';
$txt['record'] = 'Save';
$txt['function'] = 'Function';
$txt['value'] = 'Value';
$txt['add'] = 'Add';
$txt['display_records'] = 'Record display';
$txt['nb_records'] = 'Number of records in the table';
$txt['empty_tbl'] = 'The table is empty';
$txt['emptyer_tbl'] = 'Empty table';
$txt['emptyer_tbls'] = 'Empty tables';
$txt['tbl_renamed'] = 'The table is now called';
$txt['back'] = 'Back';
$txt['old_name'] = 'Old name';
$txt['new_name'] = 'New name';
$txt['rename'] = 'Rename';
$txt['invalid_dest'] = 'Destination table is not valid !';
$txt['the_tbl'] = 'The table';
$txt['copy_successful'] = 'has been copied successfully';
$txt['dest'] = 'Destination';
$txt['structure'] = 'Structure';
$txt['data_struc'] = 'Structure + datas';
$txt['copy_tbl'] = 'Copy the table';
$txt['move_successful'] = 'has been moved successfully';
$txt['move'] = 'Move';
$txt['modif_done'] = 'Modifications done';
$txt['choose_field'] = 'Choose at least a field';
$txt['confirm_delete'] = 'Are you sure you want to delete those fields';
$txt['after'] = 'After';
$txt['position'] = 'Position';
$txt['tbl_begin'] = 'Begin of the table';
$txt['tbl_end'] = 'End of the table';
$txt['the_key'] = 'The key';
$txt['been_deleted'] = 'has been deleted';
$txt['confirm_key'] = 'Are you sure you want to delete the key';
$txt['type_now'] = 'has now a type';
$txt['CtrlA'] = 'Select all';
$txt['launch_query'] = 'Launch the query';
$txt['incoming_sql'] = 'Dump insertion';
$txt['no_incoming_sql'] = 'No sql file found in <b>incoming/</b> directory';
$txt['no_incoming_dir'] = 'No <B>incoming/</B> directory';
$txt['display'] = 'Display';
$txt['displaying'] = 'Displaying';
$txt['timed_query'] = 'Query took';
$txt['secondes'] = 'seconds';
$txt['done_queries'] = 'queries(s) done';
$txt['multiple_queries'] = 'Multiple queries';
$txt['close_popup'] = 'Close the popup';
$txt['close_window'] = 'Close this window';
$txt['next'] = 'Next';
$txt['host'] = 'Host';
$txt['user'] = 'User';
$txt['password'] = 'Password';
$txt['apply'] = 'Apply';
$txt['ok'] = 'ok';
$txt['default_value'] = 'Default value';
$txt['tips_day'] = 'Tip of the day';
$txt['next_tip'] = 'Next tip';
$txt['dont_show_again'] = 'Don\'t show again';
$txt['upload_csv'] = 'You can insert a CSV file';
$txt['upload_sql'] = 'You can insert a SQL file';
$txt['on_this_page'] = 'on this page';
$txt['dump_this_query'] = 'Dump with this query';
$txt['new_type'] = 'New table type';
$txt['sure_update'] = 'Are you sure you want to update all records ?';
$txt['order_by'] = 'Order by';
$txt['where'] = 'WHERE';
$txt['criteria'] = 'Criteria';
$txt['order'] = 'Order';
$txt['input_invalid'] = 'Invalid input';
$txt['action_mult'] = 'Action on selected tables';
$txt['show_mysql_state'] = 'Show MySQL server\'s state';
$txt['show_mysql_vars'] = 'Show MySQL server\'s variables';
$txt['show_mysql_process'] = 'Show MySQL server\'s process';
$txt['not_allowed'] = 'You\'re not allowed to view this page';
$txt['show_full_text'] = 'Show full texts';
$txt['hide_full_text'] = 'Hide texts';
$txt['setup_nb_char_blob'] = 'Number of chars shown for BLOB and TEXT types';
$txt['setup_nb_chars_add_on'] = 'To show all the text, type 0';
$txt['setup_cant_save'] = 'A technical incompatibility prevents from saving your configuration.<BR>To save it, click on "Select all", and upload the content in the file';
$txt['setup_cant_save_2'] = ' in the directory you\'ve installed eSKUeL on your FTP.';
$txt['error_occured'] = 'An error occured';
$txt['empty'] = 'Empty';
$txt['fixed'] = 'Fixed';
$txt['dynamic'] = 'Dynamic';
$txt['compressed'] = 'Compressed';
$txt['upload_not_allowed'] = 'Upload is forbidden by your hosting service. You cannot upload via HTTP';
$txt['desc_tbls'] = 'Tables structure';
$txt['desc_in_progress'] = 'Strucuture display in progress';
$txt['null'] = 'Null';

$txt['dump_structure_only'] = 'Structure only';
$txt['dump_structure_data'] = 'Structure + data';
$txt['dump_data_only'] = 'Data only';
$txt['dump_drop_table'] = 'Drop Table';
$txt['dump_complete_insert'] = 'Complete insertions';
$txt['dump_split'] = 'Nb of queries / file';
$txt['dump_split_expl'] = '(If 0, only one file will be created)';
$txt['dump_csv'] = 'CSV data';
$txt['dump_csv_separator'] = 'CSV separator';
$txt['dump_csv_eol'] = 'CSV end of line';
$txt['dump_query'] = 'Dump SQL query';
$txt['dump_transmit'] = 'Transmit';
$txt['dump_in_progress'] = 'Multiple dump in progress';
$txt['dump_finished'] = 'Dump finished';
$txt['dump_status'] = 'Dumping queries';
$txt['dump_must_choose_tbl'] = 'You must choose at least a table';
$txt['dump_mult'] = 'Dump tables';
$txt['dump_wait'] = 'Dump in progress, please wait until your browser send you the file';
$txt['dump_dont_start'] = 'If the download doesn\'t start, click';
$txt['dump_here'] = 'here';
$txt['dump_file'] = 'File';
$txt['dump_replace'] = 'Replace table\'s data';
$txt['dump_fields_terminated'] = 'Fields terminated by';
$txt['dump_fields_surrounded'] = 'Fields surrounded by';
$txt['dump_special_char'] = 'Special character';
$txt['dump_lines_terminated'] = 'Lines terminated by';
$txt['dump_columns_names'] = 'Columns Names';

$txt['setup_title'] = 'eSKUeL\'s configuration';
$txt['setup_name'] = 'Configuration\'s name';
$txt['setup_add_entry'] = 'Add new configuration';
$txt['setup_mod_entry'] = 'Modify configuration';
$txt['setup_mod_globals'] = 'Modify global variables';
$txt['setup_del_entry'] = 'Delete configuration';
$txt['setup_del_tpl'] = 'Delete skin';
$txt['setup_return_eskuel'] = 'Back to eSKUeL';
$txt['setup_only_db'] = 'Only database';
$txt['setup_tpl'] = 'Skin';
$txt['setup_sure'] = 'Are you sure you want to delete';
$txt['setup_mod_cfg_nb'] = 'Modifying config N';
$txt['setup_back_hp'] = 'Back to home page';
$txt['setup_tpl_create'] = 'Create a new skin';
$txt['setup_tpl_mod'] = 'Modify a skin';
$txt['setup_defaultPerRequest'] = 'Default number of results';
$txt['setup_defaultConf'] = 'Default configuration';
$txt['setup_defaultTxt'] = 'Default language';
$txt['setup_tipsOfTheDay'] = 'Show tip of the day';
$txt['setup_siteUrl'] = 'Site URL';
$txt['setup_tpl_type'] = 'Skin type';
$txt['setup_3_columns'] = '3 columns';
$txt['setup_2_columns'] = '2 columns';
$txt['setup_install'] = 'eSKUeL installation';
$txt['setup_language'] = 'Choose your language';
$txt['setup_connection_cfg'] = 'Connection setup';
$txt['setup_global_vars'] = 'Global variables setup';
$txt['setup_step'] = 'Step';
$txt['setup_back_2_lang'] = 'Back to language setup';
$txt['setup_error_install'] = 'You haven\'t filled all the required fields';
$txt['setup_congratulation'] = 'Congratulations !<BR><BR>You have correctly installed eSKUeL';
$txt['setup_config_saved'] = 'Configuration saved';
$txt['setup_hostname'] = 'Hostname of the MySQL server';
$txt['setup_login'] = 'Your login (username)';
$txt['setup_onlydb'] = 'Name of your database if you\'ve got only one';
$txt['setup_defaultPerRequest_expl'] = 'Number of rows returned per page for a query';
$txt['setup_siteUrl_expl'] = 'The URL of your website (used for the logo)';
$txt['setup_mysql_state'] = 'Show MySQL\'s state';
$txt['setup_mysql_vars'] = 'Show MySQL\'s variables';
$txt['setup_mysql_process'] = 'Show MySQL\'s process';
$txt['setup_give_name_skin'] = 'Please give a name to your skin';
$txt['setup_another_name'] = 'Directory already exists, please choose another name for your skin';
$txt['setup_cant_delete_cfg'] = 'You can\'t delete your last setup';
$txt['setup_not_supported_windows'] = 'Not supported under Windows';

$txt['colorpicker'] = 'Color Picker';
$txt['colorselect'] = 'Select a color';
$txt['more'] = 'More colors';
$txt['color_bg'] = 'Page background';
$txt['color_tbl_bg'] = 'Table background';
$txt['color_titre_bg'] = 'Titles background';
$txt['color_titre_font'] = 'Titles';
$txt['color_border'] = 'Border';
$txt['color_vlink'] = 'Visited links';
$txt['color_link'] = 'Links';
$txt['color_text'] = 'Text';
$txt['color_alink'] = 'Active links';
$txt['color_trou_bg'] = '"Input" background';
$txt['color_trou_font'] = '"Input" text';
$txt['color_trou_border'] = '"Input" border';
$txt['color_bosse_bg'] = 'Button background';
$txt['color_bosse_font'] = 'Button text';
$txt['color_bosse_border'] = 'Button border';
$txt['color_pick_bg'] = '"Checkbox" background';
$txt['color_pick_border'] = '"Checkbox" border';
$txt['color_preview'] = 'Preview';
$txt['color_code'] = 'Color code';
$txt['color_altern_img'] = 'Use other images';
$txt['color_title_bg'] = 'Title background image';

$txt['preview_input'] = 'Input';
$txt['preview_button'] = 'Button';
$txt['preview_pick'] = 'Checkbox';
$txt['preview_text'] = 'Text example';
$txt['preview_link'] = '<a href="'.time().'" target="_blank">Link example</a>';
$txt['preview_vlink'] = '<a href="#">Visited link example</a>';
$txt['check_version'] = 'Check for upgrade...';

$txt['help'] = 'Help';
$txt['help_chars'] = 'characters';
$txt['help_values'] = 'values';
$txt['help_members'] = 'members';
$txt['help_data_types'] = 'Help on data types';
$txt['help_not_found'] = 'Help not found';
$txt['help_close'] = 'Quit help';

$txt['bkmk_this'] = 'Bookmark this query';
$txt['bkmk_manage'] = 'Bookmarks management';
$txt['bkmk_modify'] = 'Modify the query';
$txt['bkmk_delete'] = 'Delete the query';
$txt['bkmk_add1'] = 'Add the query ';
$txt['bkmk_add2'] = ' to :';
$txt['bkmk_query'] = 'The query ';
$txt['bkmk_been_saved'] = ' has been saved';
$txt['bkmk_been_modified'] = ' has benn changed';
$txt['bkmk_been_deleted'] = 'has been deleted';
$txt['bkmk_available'] = 'Available queries';
?>

==> eskuel_1.0.6.orig.tar.gz: eskuel-1.0.6/lang/english.inc.php <==
<?php

$txt['config_name'] = 'english';

$txt['charset'] = 'ISO-8859-1';



$txt['Yes'] = 'Yes';

$txt['No'] = 'No';

$txt['language'] = 'Language';

$txt['close'] = 'Close';

$txt['create_tbl'] = 'Create a new table';

$txt['add_field'] = 'Add a field';

$txt['change_type'] = 'Change type';

$txt['select'] = 'Select';

$txt['options'] = 'Options';

$txt['setup'] = 'Setup';

$txt['install'] = 'Installation';

$txt['create_db'] = 'Create a database';

$txt['manual_request'] = 'Manual query';

$txt['delete_db'] = 'Delete this database';

$txt['display_content'] = 'Show the content';

$txt['add_record'] = 'Add a record';

$txt['add_comment'] = 'Modify comment';

$txt['dump_tbl'] = 'Dump the table';

$txt['rename_tbl'] = 'Rename the table';

$txt['copy_tbl'] = 'Copy the table';

$txt['move_tbl'] = 'Move the table';

$txt['order_tbl'] = 'Order table';

$txt['order_tbl_by'] = 'Order table by';

$txt['delete_tbl'] = 'Drop the table';

$txt['delete_tbls'] = 'Drop the tables';

$txt['check_tbl'] = 'Check the table';

$txt['analyse_tbl'] = 'Analyze the table';

$txt['repare_tbl'] = 'Repair the table';

$txt['optimize_tbl'] = 'Optimize the table';

$txt['optimize_tbls'] = 'Optimize the tables';

$txt['back_2_tbl'] = 'Back to table';

$txt['back_2_db'] = 'Back to database';

$txt['execute'] = 'Execute';

$txt['no_tbl'] = 'No table in this database.';

$txt['tbl'] = 'Table';

$txt['db'] = 'Database';

$txt['records'] = 'Records';

$txt['size'] = 'Size';

$txt['records2'] = 'record(s)';

$txt['tbl_name'] = 'Table\'s name';

$txt['nb_fields'] = 'Number of fields';

$txt['create_the_tbl'] = 'Create the table';

$txt['tbl_creation'] = 'Creating table';

$txt['key'] = 'Key';

$txt['field_name'] = 'Field\'s name';

$txt['type'] = 'Type';

$txt['can_be_null'] = 'Can be null';

$txt['length'] = 'Length';

$txt['propose_opt'] = 'Propose structural optimisations on the table';

$txt['cardinality'] = 'Cardinality';

$txt['primary'] = 'Primary';

$txt['index'] = 'Index';

$txt['unique'] = 'Unique';

$txt['fulltext'] = 'Full text';

$txt['attribs'] = 'Attributes';

$txt['default_value'] = 'Default value';

$txt['auto_incr'] = 'Auto increment';

$txt['comments'] = 'Comments';

$txt['sql_query'] = 'SQL Query';

$txt['tbl_created'] = 'Table has been successfully created';

$txt['no_records'] = 'No records';

$txt['from'] = 'From';

$txt['to'] = 'to';

$txt['modify'] = 'Modify';

$txt['delete'] = 'Delete';

$txt['cancel'] = 'Cancel';

$txt['query_done'] = 'Query done';

$txt['confirm_query'] = 'Are you sure you want to do';

$txt['query_is_about'] = 'The query concern';

$txt['tbl2'] = 'table(s)';

$txt['and'] = 'and';

$txt['the_db'] = 'The database';

$txt['has_been_created'] = 'has been created';

$txt['db_name'] = 'Database\'s name';

$txt['create_the_db'] = 'Create the database';

$txt['name'] = 'Name';

$txt['xtra'] = 'Extra';

$txt['choice'] = 'Selection';

$txt['delete_choice'] = 'Delete selection';

$txt['modif_choice'] = 'Modify selection';

$txt['field'] = 'Field';

$txt['fields'] = 'Fields';

$txt['never_done'] = 'Never done';

$txt['next_auto'] = 'Next "auto_increment"';

$txt['tbl_comment'] = 'Table comment';

$txt['type_records'] = 'Records type';

$txt['record_size'] = 'Average record size';

$txt['data_size'] = 'Data size';

$txt['index_size'] = 'Index size';

$txt['creation_date'] = 'Creation date';

$txt['last_update_date'] = 'Last update';

$txt['last_check_date'] = 'Last check';

$txt['lost_space'] = 'Warning lost space';

$txt['unit'] = 'octets';

$txt['comment_recorded'] = 'Comment saved';

$txt['a_comment'] = 'Comment';

$txt['record'] = 'Save';

$txt['function'] = 'Function';

$txt['value'] = 'Value';

$txt['add'] = 'Add';

$txt['display_records'] = 'Record display';

$txt['nb_records'] = 'Number of records in the table';

$txt['empty_tbl'] = 'The table is empty';

$txt['emptyer_tbl'] = 'Empty table';

$txt['emptyer_tbls'] = 'Empty tables';

$txt['tbl_renamed'] = 'The table is now called';

$txt['back'] = 'Back';

$txt['old_name'] = 'Old name';

$txt['new_name'] = 'New name';

$txt['rename'] = 'Rename';

$txt['invalid_dest'] = 'Destination table is not valid !';

$txt['the_tbl'] = 'The table';

$txt['copy_successful'] = 'has been copied successfully';

$txt['dest'] = 'Destination';

$txt['structure'] = 'Structure';

$txt['data_struc'] = 'Structure + datas';

$txt['copy_tbl'] = 'Copy the table';

$txt['move_successful'] = 'has been moved successfully';

$txt['move'] = 'Move';

$txt['modif_done'] = 'Modifications done';

$txt['choose_field'] = 'Choose at least a field';

$txt['confirm_delete'] = 'Are you sure you want to delete those fields';

$txt['after'] = 'After';

$txt['position'] = 'Position';

$txt['tbl_begin'] = 'Begin of the table';

$txt['tbl_end'] = 'End of the table';

$txt['the_key'] = 'The key';

$txt['been_deleted'] = 'has been deleted';

$txt['confirm_key'] = 'Are you sure you want to delete the key';

$txt['type_now'] = 'has now a type';

$txt['CtrlA'] = 'Select all';

$txt['launch_query'] = 'Launch the query';

$txt['incoming_sql'] = 'Dump insertion';

$txt['no_incoming_sql'] = 'No sql file found in <b>incoming/</b> directory';

$txt['no_incoming_dir'] = 'No <B>incoming/</B> directory';

$txt['display'] = 'Display';

$txt['displaying'] = 'Displaying';

$txt['timed_query'] = 'Query took';

$txt['secondes'] = 'seconds';

$txt['done_queries'] = 'queries(s) done';

$txt['multiple_queries'] = 'Multiple queries';

$txt['close_popup'] = 'Close the popup';

$txt['close_window'] = 'Close this window';

$txt['next'] = 'Next';

$txt['host'] = 'Host';

$txt['user'] = 'User';

$txt['password'] = 'Password';

$txt['apply'] = 'Apply';

$txt['ok'] = 'ok';

$txt['default_value'] = 'Default value';

$txt['tips_day'] = 'Tip of the day';

$txt['next_tip'] = 'Next tip';

$txt['dont_show_again'] = 'Don\'t show again';

$txt['upload_csv'] = 'You can insert a CSV file';

$txt['upload_sql'] = 'You can insert a SQL file';

$txt['on_this_page'] = 'on this page';

$txt['dump_this_query'] = 'Dump with this query';

$txt['new_type'] = 'New table type';

$txt['sure_update'] = 'Are you sure you want to update all records ?';

$txt['order_by'] = 'Order by';

$txt['where'] = 'WHERE';

$txt['criteria'] = 'Criteria';

$txt['order'] = 'Order';

$txt['input_invalid'] = 'Invalid input';

$txt['action_mult'] = 'Action on selected tables';

$txt['show_mysql_state'] = 'Show MySQL server\'s state';

$txt['show_mysql_vars'] = 'Show MySQL server\'s variables';

$txt['show_mysql_process'] = 'Show MySQL server\'s process';

$txt['not_allowed'] = 'You\'re not allowed to view this page';

$txt['show_full_text'] = 'Show full texts';

$txt['hide_full_text'] = 'Hide texts';

$txt['setup_nb_char_blob'] = 'Number of chars shown for BLOB and TEXT types';

$txt['setup_nb_chars_add_on'] = 'To show all the text, type 0';

$txt['setup_cant_save'] = 'A technical incompatibility prevents from saving your configuration.<BR>To save it, click on "Select all", and upload the content in the file (create it or overwrite it) ';

$txt['setup_cant_save_2'] = ' in the directory you\'ve installed eSKUeL on your FTP.';

$txt['error_occured'] = 'An error occured';

$txt['empty'] = 'Empty';

$txt['fixed'] = 'Fixed';

$txt['dynamic'] = 'Dynamic';

$txt['compressed'] = 'Compressed';

$txt['upload_not_allowed'] = 'Upload is forbidden by your hosting service. You cannot upload via HTTP';

$txt['desc_tbls'] = 'Tables structure';

$txt['desc_in_progress'] = 'Strucuture display in progress';

$txt['null'] = 'Null';

$txt['horizontal_mode'] = 'Horizontal mode';

$txt['vertical_mode'] = 'Vertical mode';

$txt['filter'] = 'Filter';

$txt['filter_db'] = 'Filter databases';

$txt['filter_tbl'] = 'Filter tables';

$txt['overwrite'] = 'Overwrite destination table';

$txt['expl_enum'] = '<SUP>*</SUP>If the field is ENUM or SET, enter the values like this : \'value1\', \'value2\'... if a  \\ or a \' is needed, add a \\ (ex : \\\\ for \ and \\\' for \')';

$txt['explain'] = 'Explain this query';



$txt['dump_structure_only'] = 'Structure only';

$txt['dump_structure_data'] = 'Structure + data';

$txt['dump_data_only'] = 'Data only';

$txt['dump_drop_table'] = 'Drop Table';

$txt['dump_complete_insert'] = 'Complete insertions';

$txt['dump_split'] = 'Nb of queries / file';

$txt['dump_split_expl'] = '(If 0, only one file will be created)';

$txt['dump_csv'] = 'CSV data';

$txt['dump_csv_separator'] = 'CSV separator';

$txt['dump_csv_eol'] = 'CSV end of line';

$txt['dump_query'] = 'Dump SQL query';

$txt['dump_transmit'] = 'Transmit';

$txt['dump_in_progress'] = 'Multiple dump in progress';

$txt['dump_finished'] = 'Dump finished';

$txt['dump_status'] = 'Dumping queries';

$txt['dump_must_choose_tbl'] = 'You must choose at least a table';

$txt['dump_mult'] = 'Dump tables';

$txt['dump_wait'] = 'Dump in progress, please wait until your browser send you the file';

$txt['dump_dont_start'] = 'If the download doesn\'t start, click';

$txt['dump_here'] = 'here';

$txt['dump_file'] = 'File';

$txt['dump_replace'] = 'Replace table\'s data';

$txt['dump_fields_terminated'] = 'Fields terminated by';

$txt['dump_fields_surrounded'] = 'Fields surrounded by';

$txt['dump_special_char'] = 'Special character';

$txt['dump_lines_terminated'] = 'Lines terminated by';

$txt['dump_columns_names'] = 'Columns Names';

$txt['dump_protect'] = 'Protect fields and tables name with ``';

$txt['dump_xml'] = 'XML Dump';

$txt['dump_zip'] = 'Zip compression';

$txt['dump_gzip'] = 'Gzip compression';

$txt['dump_bzip'] = 'Bzip compression';



$txt['setup_title'] = 'eSKUeL\'s configuration';

$txt['setup_name'] = 'Configuration\'s name';

$txt['setup_add_entry'] = 'Add new configuration';

$txt['setup_mod_entry'] = 'Modify configuration';

$txt['setup_mod_globals'] = 'Modify global variables';

$txt['setup_del_entry'] = 'Delete configuration';

$txt['setup_del_tpl'] = 'Delete skin';

$txt['setup_return_eskuel'] = 'Back to eSKUeL';

$txt['setup_only_db'] = 'Only database';

$txt['setup_tpl'] = 'Skin';

$txt['setup_sure'] = 'Are you sure you want to delete';

$txt['setup_mod_cfg_nb'] = 'Modifying config N';

$txt['setup_back_hp'] = 'Back to home page';

$txt['setup_tpl_create'] = 'Create a new skin';

$txt['setup_tpl_mod'] = 'Modify a skin';

$txt['setup_defaultPerRequest'] = 'Default number of results';

$txt['setup_defaultConf'] = 'Default configuration';

$txt['setup_defaultTxt'] = 'Default language';

$txt['setup_tipsOfTheDay'] = 'Show tip of the day';

$txt['setup_manualPopup'] = 'Popup';

$txt['setup_manualDHTML'] = 'DHTML';

$txt['setup_siteUrl'] = 'Site URL';

$txt['setup_tpl_type'] = 'Skin type';

$txt['setup_3_columns'] = '3 columns';

$txt['setup_2_columns'] = '2 columns';

$txt['setup_install'] = 'eSKUeL installation';

$txt['setup_language'] = 'Choose your language';

$txt['setup_connection_cfg'] = 'Connection setup';

$txt['setup_global_vars'] = 'Global variables setup';

$txt['setup_step'] = 'Step';

$txt['setup_back_2_lang'] = 'Back to language setup';

$txt['setup_error_install'] = 'You haven\'t filled all the required fields';

$txt['setup_congratulation'] = 'Congratulations !<BR><BR>You have correctly installed eSKUeL';

$txt['setup_config_saved'] = 'Configuration saved';

$txt['setup_hostname'] = 'Hostname of the MySQL server';

$txt['setup_login'] = 'Your login (username)';

$txt['setup_onlydb'] = 'Name of your database if you\'ve got only one';

$txt['setup_defaultPerRequest_expl'] = 'Number of rows returned per page for a query';

$txt['setup_siteUrl_expl'] = 'The URL of your website (used for the logo)';

$txt['setup_mysql_state'] = 'Show MySQL\'s state';

$txt['setup_mysql_vars'] = 'Show MySQL\'s variables';

$txt['setup_mysql_process'] = 'Show MySQL\'s process';

$txt['setup_give_name_skin'] = 'Please give a name to your skin';

$txt['setup_another_name'] = 'Directory already exists, please choose another name for your skin';

$txt['setup_cant_delete_cfg'] = 'You can\'t delete your last setup';

$txt['setup_not_supported_windows'] = 'Not supported under Windows';



$txt['colorpicker'] = 'Color Picker';

$txt['colorselect'] = 'Select a color';

$txt['more'] = 'More colors';

$txt['color_bg'] = 'Page background';

$txt['color_tbl_bg'] = 'Table background';

$txt['color_titre_bg'] = 'Titles background';

$txt['color_titre_font'] = 'Titles';

$txt['color_border'] = 'Border';

$txt['color_vlink'] = 'Visited links';

$txt['color_link'] = 'Links';

$txt['color_text'] = 'Text';

$txt['color_alink'] = 'Active links';

$txt['color_trou_bg'] = '"Input" background';

$txt['color_trou_font'] = '"Input" text';

$txt['color_trou_border'] = '"Input" border';

$txt['color_bosse_bg'] = 'Button background';

$txt['color_bosse_font'] = 'Button text';

$txt['color_bosse_border'] = 'Button border';

$txt['color_pick_bg'] = '"Checkbox" background';

$txt['color_pick_border'] = '"Checkbox" border';

$txt['color_preview'] = 'Preview';

$txt['color_code'] = 'Color code';

$txt['color_altern_img'] = 'Use other images';

$txt['color_title_bg'] = 'Title background image';



$txt['preview_input'] = 'Input';

$txt['preview_button'] = 'Button';

$txt['preview_pick'] = 'Checkbox';

$txt['preview_text'] = 'Text example';

$txt['preview_link'] = '<a href="'.time().'" target="_blank">Link example</a>';

$txt['preview_vlink'] = '<a href="#">Visited link example</a>';

$txt['check_version'] = 'Check for upgrade...';



$txt['help'] = 'Help';

$txt['help_chars'] = 'characters';

$txt['help_values'] = 'values';

$txt['help_members'] = 'members';

$txt['help_data_types'] = 'Help on data types';

$txt['help_not_found'] = 'Help not found';

$txt['help_close'] = 'Quit help';



$txt['bkmk_this'] = 'Bookmark this query';

$txt['bkmk_manage'] = 'Bookmarks management';

$txt['bkmk_modify'] = 'Modify the query';

$txt['bkmk_delete'] = 'Delete the query';

$txt['bkmk_add1'] = 'Add the query ';

$txt['bkmk_add2'] = ' to :';

$txt['bkmk_query'] = 'The query ';

$txt['bkmk_been_saved'] = ' has been saved';

$txt['bkmk_been_modified'] = ' has benn changed';

$txt['bkmk_been_deleted'] = 'has been deleted';

$txt['bkmk_available'] = 'Available queries';



$txt['adm_all'] = 'All';

$txt['adm_all_f'] = 'All';



?>
